The library provides a collection of tools and functionality for the Scoota Platform services.

![Python Version](https://img.shields.io/pypi/pyversions/rbx.svg)

## Installation

Install this library in a virtualenv using pip.

```
pip install rbx
```

> See the [wiki](https://github.com/rockabox/rbx/wiki) for more details on the contents of this library.

# Development

To contribute to this project, install and run `tox`:

```
pip install -r tests/setup.txt
tox -m local
```
